/*	$Id: ort-lang-nodejs.h,v 1.8 2021/07/12 13:37:24 kristaps Exp $ */
/*
 * Copyright (c) 2020 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef ORT_LANG_NODEJS
#define ORT_LANG_NODEJS

#define	ORT_LANG_NODEJS_VALID		0x01
#define	ORT_LANG_NODEJS_CORE		0x02
#define ORT_LANG_NODEJS_DB		0x04
#define	ORT_LANG_NODEJS_NOMODULE	0x08

struct ort_lang_nodejs {
	unsigned int	 flags;
};

int	 ort_lang_nodejs(const struct ort_lang_nodejs *,
		const struct config *, FILE *f);

#endif
